/* wizard-source.c generated by valac 0.36.1.38-6532, the Vala compiler
 * generated from wizard-source.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <osinfo/osinfo.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_WIZARD_SCROLLED (boxes_wizard_scrolled_get_type ())
#define BOXES_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled))
#define BOXES_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))
#define BOXES_IS_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_IS_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_WIZARD_SCROLLED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))

typedef struct _BoxesWizardScrolled BoxesWizardScrolled;
typedef struct _BoxesWizardScrolledClass BoxesWizardScrolledClass;
typedef struct _BoxesWizardScrolledPrivate BoxesWizardScrolledPrivate;
enum  {
	BOXES_WIZARD_SCROLLED_DUMMY_PROPERTY,
	BOXES_WIZARD_SCROLLED_LAST_PROPERTY
};
static GParamSpec* boxes_wizard_scrolled_properties[BOXES_WIZARD_SCROLLED_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_WIZARD_MEDIA_ENTRY (boxes_wizard_media_entry_get_type ())
#define BOXES_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry))
#define BOXES_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))
#define BOXES_IS_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_IS_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_WIZARD_MEDIA_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))

typedef struct _BoxesWizardMediaEntry BoxesWizardMediaEntry;
typedef struct _BoxesWizardMediaEntryClass BoxesWizardMediaEntryClass;
typedef struct _BoxesWizardMediaEntryPrivate BoxesWizardMediaEntryPrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
enum  {
	BOXES_WIZARD_MEDIA_ENTRY_DUMMY_PROPERTY,
	BOXES_WIZARD_MEDIA_ENTRY_LAST_PROPERTY
};
static GParamSpec* boxes_wizard_media_entry_properties[BOXES_WIZARD_MEDIA_ENTRY_LAST_PROPERTY];
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
enum  {
	BOXES_WIZARD_SOURCE_DUMMY_PROPERTY,
	BOXES_WIZARD_SOURCE_SELECTED,
	BOXES_WIZARD_SOURCE_URI,
	BOXES_WIZARD_SOURCE_INSTALL_MEDIA,
	BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER,
	BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED,
	BOXES_WIZARD_SOURCE_PAGE,
	BOXES_WIZARD_SOURCE_LAST_PROPERTY
};
static GParamSpec* boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_LAST_PROPERTY];

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
typedef struct _Block91Data Block91Data;
typedef struct _Block92Data Block92Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesWizardSourceAddMediaEntriesData BoxesWizardSourceAddMediaEntriesData;
typedef struct _Block93Data Block93Data;
typedef struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
enum  {
	BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL,
	BOXES_WIZARD_SOURCE_LAST_SIGNAL
};
static guint boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_LAST_SIGNAL] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

typedef gboolean (*ClickedFunc) (void* user_data);
struct _BoxesWizardScrolled {
	GtkScrolledWindow parent_instance;
	BoxesWizardScrolledPrivate * priv;
	GtkBox* vbox;
};

struct _BoxesWizardScrolledClass {
	GtkScrolledWindowClass parent_class;
};

struct _BoxesWizardScrolledPrivate {
	gint _num_visible;
};

struct _BoxesWizardMediaEntry {
	GtkButton parent_instance;
	BoxesWizardMediaEntryPrivate * priv;
	BoxesInstallerMedia* media;
};

struct _BoxesWizardMediaEntryClass {
	GtkButtonClass parent_class;
};

struct _BoxesWizardMediaEntryPrivate {
	GtkImage* media_image;
	GtkLabel* title_label;
	GtkLabel* details_label;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardSourcePrivate {
	GtkWidget* _selected;
	BoxesInstallerMedia* _install_media;
	BoxesLibvirtSystemImporter* _libvirt_sys_importer;
	GtkBox* main_vbox;
	BoxesWizardScrolled* media_scrolled;
	GtkBox* url_entry_vbox;
	GtkButton* select_file_button;
	GtkButton* libvirt_sys_import_button;
	GtkLabel* libvirt_sys_import_label;
	BoxesAppWindow* window;
	GtkBox* media_vbox;
	BoxesSourcePage _page;
};

struct _Block91Data {
	int _ref_count_;
	BoxesWizardSource* self;
	BoxesOSDatabase* os_db;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _Block92Data {
	int _ref_count_;
	Block91Data * _data91_;
	GtkListStore* url_store;
};

struct _BoxesWizardSourceAddMediaEntriesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesWizardSource* self;
	GList* medias;
	BoxesMediaManager* _tmp0_;
	GList* _tmp1_;
	GtkBox* _tmp2_;
	GList* _tmp3_;
	GList* child_collection;
	GList* child_it;
	GtkWidget* child;
	BoxesInstallerMedia* child_media;
	GtkWidget* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	gboolean obsolete;
	GList* _tmp7_;
	GList* media_collection;
	GList* media_it;
	BoxesInstallerMedia* _tmp8_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp9_;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp13_;
	GtkBox* _tmp14_;
	GtkWidget* _tmp15_;
	GList* _tmp16_;
	GList* _vala1_media_collection;
	GList* _vala1_media_it;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _vala1_media;
	gboolean nouveau;
	GtkBox* _tmp18_;
	GList* _tmp19_;
	GList* _vala1_child_collection;
	GList* _vala1_child_it;
	GtkWidget* _vala1_child;
	BoxesInstallerMedia* _vala1_child_media;
	GtkWidget* _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	BoxesInstallerMedia* _tmp23_;
	const gchar* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	const gchar* _tmp26_;
	gboolean _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	GtkBox* _tmp29_;
	GList* _tmp30_;
	GList* _tmp31_;
	guint _tmp32_;
	gboolean _tmp33_;
	BoxesWizardScrolled* _tmp34_;
};

struct _Block93Data {
	int _ref_count_;
	BoxesWizardSource* self;
	BoxesWizardMediaEntry* entry;
	BoxesInstallerMedia* media;
};

struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesWizardSource* self;
	BoxesLibvirtSystemImporter* _tmp0_;
	BoxesLibvirtSystemImporter* _tmp1_;
	GError* _error_;
	GError* _tmp2_;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_;
	BoxesLibvirtSystemImporter* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkButton* _tmp9_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesWizardWindowFileChosenFunc) (const gchar* uri, void* user_data);

static gpointer boxes_wizard_scrolled_parent_class = NULL;
static gpointer boxes_wizard_media_entry_parent_class = NULL;
static gpointer boxes_wizard_source_parent_class = NULL;

GType boxes_source_page_get_type (void) G_GNUC_CONST;
GType boxes_wizard_scrolled_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SCROLLED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledPrivate))
void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible);
static void boxes_wizard_scrolled_set_num_visible (BoxesWizardScrolled* self, gint value);
static void __lambda57_ (BoxesWizardScrolled* self);
static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda58_ (BoxesWizardScrolled* self);
static void ___lambda58__gtk_widget_show (GtkWidget* _sender, gpointer self);
static void __lambda59_ (BoxesWizardScrolled* self);
static void ___lambda59__gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height);
static gint boxes_wizard_scrolled_get_num_visible (BoxesWizardScrolled* self);
BoxesWizardScrolled* boxes_wizard_scrolled_new (void);
BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type);
static void boxes_wizard_scrolled_finalize (GObject * obj);
static void _vala_boxes_wizard_scrolled_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_scrolled_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_wizard_media_entry_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryPrivate))
BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media);
BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static void boxes_wizard_media_entry_finalize (GObject * obj);
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourcePrivate))
void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
static Block91Data* block91_data_ref (Block91Data* _data91_);
static void block91_data_unref (void * _userdata_);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_all_media_urls_as_store (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
GtkListStore* boxes_os_database_get_all_media_urls_as_store_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void __lambda60_ (Block91Data* _data91_, GObject* db, GAsyncResult* _result_);
static Block92Data* block92_data_ref (Block92Data* _data92_);
static void block92_data_unref (void * _userdata_);
static gboolean ___lambda61_ (Block92Data* _data92_, GtkEntryCompletion* store, const gchar* key, GtkTreeIter* iter);
static gboolean ____lambda61__gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self);
static void ___lambda60__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_url_entry_activated (BoxesWizardSource* self);
static void _boxes_wizard_source_on_url_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_add_media_entries_data_free (gpointer _data);
static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static Block93Data* block93_data_ref (Block93Data* _data93_);
static void block93_data_unref (void * _userdata_);
static void __lambda69_ (Block93Data* _data93_);
static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void ___lambda69__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_);
void boxes_libvirt_system_importer_new (GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_new_finish (GAsyncResult* _res_, GError** error);
void boxes_libvirt_system_importer_construct (GType object_type, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_construct_finish (GAsyncResult* _res_, GError** error);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value);
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
gchar* boxes_libvirt_system_importer_get_wizard_menu_label (BoxesLibvirtSystemImporter* self);
static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
void boxes_wizard_window_show_file_chooser (BoxesWizardWindow* self, BoxesWizardWindowFileChosenFunc file_chosen_func, void* file_chosen_func_target, GDestroyNotify file_chosen_func_target_destroy_notify);
static void __lambda134_ (BoxesWizardSource* self, const gchar* uri);
static void ___lambda134__boxes_wizard_window_file_chosen_func (const gchar* uri, gpointer self);
static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
BoxesWizardSource* boxes_wizard_source_new (void);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self);
static gboolean _vala_string_array_contains (const gchar* * stack, int stack_length, const gchar* needle);
static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_draw_as_css_box (GtkWidget* widget);
static void boxes_wizard_source_finalize (GObject * obj);
static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* BOXES_WIZARD_SOURCE_page_names[2] = {"main-page", "url-page"};

GType boxes_source_page_get_type (void) {
	static volatile gsize boxes_source_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_source_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SOURCE_PAGE_MAIN, "BOXES_SOURCE_PAGE_MAIN", "main"}, {BOXES_SOURCE_PAGE_URL, "BOXES_SOURCE_PAGE_URL", "url"}, {BOXES_SOURCE_PAGE_LAST, "BOXES_SOURCE_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_source_page_type_id;
		boxes_source_page_type_id = g_enum_register_static ("BoxesSourcePage", values);
		g_once_init_leave (&boxes_source_page_type_id__volatile, boxes_source_page_type_id);
	}
	return boxes_source_page_type_id__volatile;
}


static void __lambda57_ (BoxesWizardScrolled* self) {
#line 27 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_queue_resize ((GtkWidget*) self);
#line 625 "wizard-source.c"
}


static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda57_ ((BoxesWizardScrolled*) self);
#line 632 "wizard-source.c"
}


static void __lambda58_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 30 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-menu-scrolled");
#line 31 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 644 "wizard-source.c"
}


static void ___lambda58__gtk_widget_show (GtkWidget* _sender, gpointer self) {
#line 29 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda58_ ((BoxesWizardScrolled*) self);
#line 651 "wizard-source.c"
}


static void __lambda59_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_;
#line 34 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 34 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_remove_class (_tmp0_, "boxes-menu-scrolled");
#line 35 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 663 "wizard-source.c"
}


static void ___lambda59__gtk_widget_hide (GtkWidget* _sender, gpointer self) {
#line 33 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda59_ ((BoxesWizardScrolled*) self);
#line 670 "wizard-source.c"
}


void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible) {
	gint _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = num_visible;
#line 24 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_set_num_visible (self, _tmp0_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object ((GObject*) self, "notify::num-visible", (GCallback) ___lambda57__g_object_notify, self, 0);
#line 29 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 29 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp1_, "show", (GCallback) ___lambda58__gtk_widget_show, self, 0);
#line 33 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 33 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp2_, "hide", (GCallback) ___lambda59__gtk_widget_hide, self, 0);
#line 694 "wizard-source.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self ? g_object_ref (self) : NULL;
#line 701 "wizard-source.c"
}


static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height) {
	BoxesWizardScrolled * self;
	gint _vala_minimum_height = 0;
	gint _vala_natural_height = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GtkViewport* viewport = NULL;
	GtkWidget* _tmp2_;
	GtkViewport* _tmp3_;
	GtkBox* box = NULL;
	GtkViewport* _tmp4_;
	GtkWidget* _tmp5_;
	GtkBox* _tmp6_;
	gint height = 0;
	gint i = 0;
	GtkBox* _tmp7_;
	GList* _tmp8_;
	gint _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) base;
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (boxes_wizard_scrolled_parent_class)->get_preferred_height ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), &_tmp0_, &_tmp1_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp0_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp1_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_bin_get_child ((GtkBin*) self);
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_viewport_get_type ()) ? ((GtkViewport*) _tmp2_) : NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	viewport = _tmp3_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = viewport;
#line 42 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = gtk_bin_get_child ((GtkBin*) _tmp4_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_box_get_type ()) ? ((GtkBox*) _tmp5_) : NULL);
#line 42 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	box = _tmp6_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	height = 0;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	i = 0;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = box;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = gtk_container_get_children ((GtkContainer*) _tmp7_);
#line 758 "wizard-source.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		w_collection = _tmp8_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 766 "wizard-source.c"
			GtkWidget* w = NULL;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			w = (GtkWidget*) w_it->data;
#line 770 "wizard-source.c"
			{
				GtkWidget* _tmp9_;
				gboolean _tmp10_;
				gint child_height = 0;
				GtkWidget* _tmp11_;
				gint _tmp12_ = 0;
				gint _tmp13_;
				gint _tmp14_;
				gint _tmp15_;
				gint _tmp16_;
				gint _tmp17_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp9_ = w;
#line 47 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp10_ = gtk_widget_get_visible (_tmp9_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (!_tmp10_) {
#line 48 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					continue;
#line 790 "wizard-source.c"
				}
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp11_ = w;
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				gtk_widget_get_preferred_height (_tmp11_, NULL, &_tmp12_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				child_height = _tmp12_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp13_ = height;
#line 51 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp14_ = child_height;
#line 51 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				height = _tmp13_ + _tmp14_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp15_ = i;
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				i = _tmp15_ + 1;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp16_ = i;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = self->priv->_num_visible;
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp16_ == _tmp17_) {
#line 54 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					break;
#line 816 "wizard-source.c"
				}
			}
		}
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (w_collection);
#line 822 "wizard-source.c"
	}
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = _vala_minimum_height;
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = height;
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = MAX (_tmp18_, _tmp19_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp20_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = _vala_natural_height;
#line 57 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = height;
#line 57 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = MAX (_tmp21_, _tmp22_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp23_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (box);
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (viewport);
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (minimum_height) {
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		*minimum_height = _vala_minimum_height;
#line 848 "wizard-source.c"
	}
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (natural_height) {
#line 39 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		*natural_height = _vala_natural_height;
#line 854 "wizard-source.c"
	}
}


BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type) {
	BoxesWizardScrolled * self = NULL;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) g_object_new (object_type, NULL);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 865 "wizard-source.c"
}


BoxesWizardScrolled* boxes_wizard_scrolled_new (void) {
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_scrolled_construct (BOXES_TYPE_WIZARD_SCROLLED);
#line 872 "wizard-source.c"
}


static gint boxes_wizard_scrolled_get_num_visible (BoxesWizardScrolled* self) {
	gint result;
	gint _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_num_visible;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 887 "wizard-source.c"
}


static void boxes_wizard_scrolled_set_num_visible (BoxesWizardScrolled* self, gint value) {
	gint _tmp0_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 19 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->_num_visible = _tmp0_;
#line 899 "wizard-source.c"
}


static void boxes_wizard_scrolled_class_init (BoxesWizardScrolledClass * klass) {
	gint BoxesWizardScrolled_private_offset;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardScrolledPrivate));
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	((GtkWidgetClass *) klass)->get_preferred_height = (void (*) (GtkWidget *, gint*, gint*)) boxes_wizard_scrolled_real_get_preferred_height;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_scrolled_get_property;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_scrolled_set_property;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_scrolled_finalize;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardScrolled_private_offset = g_type_class_get_instance_private_offset (klass);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-scrolled.ui");
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "vbox", FALSE, G_STRUCT_OFFSET (BoxesWizardScrolled, vbox));
#line 923 "wizard-source.c"
}


static void boxes_wizard_scrolled_instance_init (BoxesWizardScrolled * self) {
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SCROLLED_GET_PRIVATE (self);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 932 "wizard-source.c"
}


static void boxes_wizard_scrolled_finalize (GObject * obj) {
	BoxesWizardScrolled * self;
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 17 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->vbox);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_scrolled_parent_class)->finalize (obj);
#line 944 "wizard-source.c"
}


GType boxes_wizard_scrolled_get_type (void) {
	static volatile gsize boxes_wizard_scrolled_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_scrolled_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardScrolledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_scrolled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardScrolled), 0, (GInstanceInitFunc) boxes_wizard_scrolled_instance_init, NULL };
		GType boxes_wizard_scrolled_type_id;
		boxes_wizard_scrolled_type_id = g_type_register_static (gtk_scrolled_window_get_type (), "BoxesWizardScrolled", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_scrolled_type_id__volatile, boxes_wizard_scrolled_type_id);
	}
	return boxes_wizard_scrolled_type_id__volatile;
}


static void _vala_boxes_wizard_scrolled_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardScrolled * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 965 "wizard-source.c"
		default:
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 971 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_scrolled_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardScrolled * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 981 "wizard-source.c"
		default:
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 15 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 987 "wizard-source.c"
	}
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media) {
	BoxesWizardMediaEntry * self = NULL;
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	OsinfoOs* _tmp3_;
	GtkLabel* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_ = FALSE;
	BoxesInstallerMedia* _tmp11_;
	OsinfoMedia* _tmp12_;
	BoxesInstallerMedia* _tmp27_;
	OsinfoMedia* _tmp28_;
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardMediaEntry*) g_object_new (object_type, NULL);
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 73 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->media = _tmp1_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = media;
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_->os;
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ != NULL) {
#line 1024 "wizard-source.c"
		GtkImage* _tmp4_;
		BoxesInstallerMedia* _tmp5_;
		OsinfoOs* _tmp6_;
#line 76 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = self->priv->media_image;
#line 76 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = media;
#line 76 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = _tmp5_->os;
#line 76 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_downloader_fetch_os_logo (_tmp4_, _tmp6_, 64, NULL, NULL);
#line 1036 "wizard-source.c"
	}
#line 78 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = self->priv->title_label;
#line 78 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = media;
#line 78 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = _tmp8_->label;
#line 78 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp7_, _tmp9_);
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = media;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = _tmp11_->os_media;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp12_ != NULL) {
#line 1052 "wizard-source.c"
		BoxesInstallerMedia* _tmp13_;
		OsinfoMedia* _tmp14_;
		gboolean _tmp15_;
		gboolean _tmp16_;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = media;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = _tmp13_->os_media;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp14_, "live", &_tmp15_, NULL);
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = _tmp15_;
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = _tmp16_;
#line 1067 "wizard-source.c"
	} else {
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = FALSE;
#line 1071 "wizard-source.c"
	}
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp10_) {
#line 1075 "wizard-source.c"
		GtkLabel* _tmp17_;
		GtkLabel* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = self->priv->title_label;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = self->priv->title_label;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = gtk_label_get_label (_tmp18_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp20_ = _tmp19_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = g_strconcat (" (", _ ("Live"), NULL);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = _tmp21_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp23_ = g_strconcat (_tmp22_, ")", NULL);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp24_ = _tmp23_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp25_ = g_strconcat (_tmp20_, _tmp24_, NULL);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp26_ = _tmp25_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp18_, _tmp26_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp26_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp24_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp22_);
#line 1114 "wizard-source.c"
	}
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp27_ = media;
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp28_ = _tmp27_->os_media;
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp28_ != NULL) {
#line 1122 "wizard-source.c"
		const gchar* _tmp29_ = NULL;
		gboolean _tmp30_ = FALSE;
		BoxesInstallerMedia* _tmp31_;
		OsinfoMedia* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gboolean _tmp36_;
		gchar* architecture = NULL;
		gchar* _tmp42_;
		GtkLabel* _tmp43_;
		const gchar* _tmp44_;
		BoxesInstallerMedia* _tmp45_;
		OsinfoOs* _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp31_ = media;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp32_ = _tmp31_->os_media;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp32_, "architecture", &_tmp33_, NULL);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp34_ = _tmp33_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp35_ = _tmp34_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp36_ = g_strcmp0 (_tmp35_, "i386") == 0;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp35_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp36_) {
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = TRUE;
#line 1157 "wizard-source.c"
		} else {
			BoxesInstallerMedia* _tmp37_;
			OsinfoMedia* _tmp38_;
			gchar* _tmp39_;
			gchar* _tmp40_;
			gchar* _tmp41_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp37_ = media;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = _tmp37_->os_media;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp38_, "architecture", &_tmp39_, NULL);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp40_ = _tmp39_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp41_ = _tmp40_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = g_strcmp0 (_tmp41_, "i686") == 0;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp41_);
#line 1178 "wizard-source.c"
		}
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp30_) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = _ ("32-bit x86 system");
#line 1184 "wizard-source.c"
		} else {
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = _ ("64-bit x86 system");
#line 1188 "wizard-source.c"
		}
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp42_ = g_strdup (_tmp29_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		architecture = _tmp42_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp43_ = self->priv->details_label;
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp44_ = architecture;
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp43_, _tmp44_);
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp45_ = media;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp46_ = _tmp45_->os;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp47_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp46_);
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp48_ = _tmp47_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp48_ != NULL) {
#line 1210 "wizard-source.c"
			GtkLabel* _tmp49_;
			GtkLabel* _tmp50_;
			const gchar* _tmp51_;
			const gchar* _tmp52_;
			BoxesInstallerMedia* _tmp53_;
			OsinfoOs* _tmp54_;
			const gchar* _tmp55_;
			const gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp49_ = self->priv->details_label;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp50_ = self->priv->details_label;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp51_ = gtk_label_get_label (_tmp50_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp52_ = _tmp51_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp53_ = media;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp54_ = _tmp53_->os;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp55_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp54_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp56_ = _tmp55_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp57_ = g_strdup_printf (_ (" from %s"), _tmp56_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp58_ = _tmp57_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp59_ = g_strconcat (_tmp52_, _tmp58_, NULL);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp60_ = _tmp59_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_label_set_label (_tmp50_, _tmp60_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp60_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp58_);
#line 1253 "wizard-source.c"
		}
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (architecture);
#line 1257 "wizard-source.c"
	}
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1261 "wizard-source.c"
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media) {
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_media_entry_construct (BOXES_TYPE_WIZARD_MEDIA_ENTRY, media);
#line 1268 "wizard-source.c"
}


static void boxes_wizard_media_entry_class_init (BoxesWizardMediaEntryClass * klass) {
	gint BoxesWizardMediaEntry_private_offset;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_media_entry_parent_class = g_type_class_peek_parent (klass);
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardMediaEntryPrivate));
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_media_entry_finalize;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardMediaEntry_private_offset = g_type_class_get_instance_private_offset (klass);
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-media-entry.ui");
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_image", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, media_image));
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, title_label));
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "details_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, details_label));
#line 1290 "wizard-source.c"
}


static void boxes_wizard_media_entry_instance_init (BoxesWizardMediaEntry * self) {
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE (self);
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1299 "wizard-source.c"
}


static void boxes_wizard_media_entry_finalize (GObject * obj) {
	BoxesWizardMediaEntry * self;
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry);
#line 63 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_image);
#line 68 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->title_label);
#line 70 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->details_label);
#line 62 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_media_entry_parent_class)->finalize (obj);
#line 1317 "wizard-source.c"
}


GType boxes_wizard_media_entry_get_type (void) {
	static volatile gsize boxes_wizard_media_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_media_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardMediaEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_media_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardMediaEntry), 0, (GInstanceInitFunc) boxes_wizard_media_entry_instance_init, NULL };
		GType boxes_wizard_media_entry_type_id;
		boxes_wizard_media_entry_type_id = g_type_register_static (gtk_button_get_type (), "BoxesWizardMediaEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_media_entry_type_id__volatile, boxes_wizard_media_entry_type_id);
	}
	return boxes_wizard_media_entry_type_id__volatile;
}


static Block91Data* block91_data_ref (Block91Data* _data91_) {
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data91_->_ref_count_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return _data91_;
#line 1338 "wizard-source.c"
}


static void block91_data_unref (void * _userdata_) {
	Block91Data* _data91_;
	_data91_ = (Block91Data*) _userdata_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data91_->_ref_count_)) {
#line 1347 "wizard-source.c"
		BoxesWizardSource* self;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self = _data91_->self;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data91_->os_db);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block91Data, _data91_);
#line 1357 "wizard-source.c"
	}
}


static Block92Data* block92_data_ref (Block92Data* _data92_) {
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data92_->_ref_count_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return _data92_;
#line 1367 "wizard-source.c"
}


static void block92_data_unref (void * _userdata_) {
	Block92Data* _data92_;
	_data92_ = (Block92Data*) _userdata_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data92_->_ref_count_)) {
#line 1376 "wizard-source.c"
		BoxesWizardSource* self;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self = _data92_->_data91_->self;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data92_->url_store);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		block91_data_unref (_data92_->_data91_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_->_data91_ = NULL;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block92Data, _data92_);
#line 1388 "wizard-source.c"
	}
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1403 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1403 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1404 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1404 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1404 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1404 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 1409 "wizard-source.c"
}


static gboolean ___lambda61_ (Block92Data* _data92_, GtkEntryCompletion* store, const gchar* key, GtkTreeIter* iter) {
	Block91Data* _data91_;
	BoxesWizardSource* self;
	gboolean result = FALSE;
	gchar* url = NULL;
	GtkTreeIter _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_;
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_ = _data92_->_data91_;
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data91_->self;
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = *iter;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_tree_model_get ((GtkTreeModel*) _data92_->url_store, &_tmp0_, 0, &url, -1);
#line 199 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = key;
#line 199 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = string_contains (url, _tmp1_);
#line 199 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp2_;
#line 199 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (url);
#line 199 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 1445 "wizard-source.c"
}


static gboolean ____lambda61__gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = ___lambda61_ (self, completion, key, iter);
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 1454 "wizard-source.c"
}


static void __lambda60_ (Block91Data* _data91_, GObject* db, GAsyncResult* _result_) {
	BoxesWizardSource* self;
	GError * _inner_error_ = NULL;
#line 186 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data91_->self;
#line 186 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (_result_ != NULL);
#line 1465 "wizard-source.c"
	{
		Block92Data* _data92_;
		GAsyncResult* _tmp0_;
		GtkListStore* _tmp1_;
		GtkEntryCompletion* completion = NULL;
		GtkEntryCompletion* _tmp2_;
		GtkEntryCompletion* _tmp3_;
		GtkEntryCompletion* _tmp4_;
		GtkCellRendererText* cell = NULL;
		GtkEntryCompletion* _tmp5_;
		GList* _tmp6_;
		GList* _tmp7_;
		gconstpointer _tmp8_;
		GtkCellRenderer* _tmp9_;
		GtkCellRendererText* _tmp10_;
		GtkCellRendererText* _tmp11_;
		GtkEntryCompletion* _tmp12_;
		GtkEntry* _tmp13_;
		GtkEntryCompletion* _tmp14_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_ = g_slice_new0 (Block92Data);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_->_ref_count_ = 1;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_->_data91_ = block91_data_ref (_data91_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _result_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = boxes_os_database_get_all_media_urls_as_store_finish (_data91_->os_db, _tmp0_, &_inner_error_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_->url_store = _tmp1_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			block92_data_unref (_data92_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data92_ = NULL;
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 1505 "wizard-source.c"
				goto __catch126_boxes_os_database_error;
			}
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			block92_data_unref (_data92_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data92_ = NULL;
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_clear_error (&_inner_error_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return;
#line 1518 "wizard-source.c"
		}
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = gtk_entry_completion_new ();
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		completion = _tmp2_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = completion;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_text_column (_tmp3_, 0);
#line 191 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = completion;
#line 191 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_model (_tmp4_, (GtkTreeModel*) _data92_->url_store);
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = completion;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = gtk_cell_layout_get_cells ((GtkCellLayout*) _tmp5_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = _tmp6_;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = g_list_nth_data (_tmp7_, (guint) 0);
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = (GtkCellRenderer*) _tmp8_;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_cell_renderer_text_get_type ()) ? ((GtkCellRendererText*) _tmp9_) : NULL;
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_tmp7_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		cell = _tmp10_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp11_ = cell;
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_set (_tmp11_, "ellipsize", PANGO_ELLIPSIZE_MIDDLE, NULL);
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp12_ = completion;
#line 194 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_match_func (_tmp12_, ____lambda61__gtk_entry_completion_match_func, block92_data_ref (_data92_), block92_data_unref);
#line 201 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = self->url_entry;
#line 201 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = completion;
#line 201 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_set_completion (_tmp13_, _tmp14_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (completion);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		block92_data_unref (_data92_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data92_ = NULL;
#line 1568 "wizard-source.c"
	}
	goto __finally126;
	__catch126_boxes_os_database_error:
	{
		GError* _error_ = NULL;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp15_ = _error_;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = _tmp15_->message;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:203: Failed to get all known media URLs: %s", _tmp16_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 1588 "wizard-source.c"
	}
	__finally126:
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 1599 "wizard-source.c"
	}
}


static void ___lambda60__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 186 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda60_ (self, source_object, res);
#line 186 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block91_data_unref (self);
#line 1609 "wizard-source.c"
}


void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window) {
	Block91Data* _data91_;
	BoxesAppWindow* _tmp0_;
	BoxesAppWindow* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesMediaManager* _tmp3_;
	BoxesOSDatabase* _tmp4_;
	BoxesOSDatabase* _tmp5_;
	BoxesOSDatabase* _tmp6_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (window != NULL);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_ = g_slice_new0 (Block91Data);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->_ref_count_ = 1;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->self = g_object_ref (self);
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = window;
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_assert (_tmp0_ != NULL, "window != null");
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = window;
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->window);
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->window = _tmp2_;
#line 185 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->media_manager;
#line 185 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = boxes_media_manager_get_os_db (_tmp3_);
#line 185 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 185 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 185 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->os_db = _tmp6_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_os_database_get_all_media_urls_as_store (_data91_->os_db, ___lambda60__gasync_ready_callback, block91_data_ref (_data91_));
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block91_data_unref (_data91_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_ = NULL;
#line 1660 "wizard-source.c"
}


void boxes_wizard_source_cleanup (BoxesWizardSource* self) {
	BoxesSourcePage _tmp0_;
	BoxesSourcePage _tmp1_;
#line 208 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 209 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_install_media (self, NULL);
#line 210 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = FALSE;
#line 211 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_wizard_source_get_page (self);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp1_ != BOXES_SOURCE_PAGE_URL) {
#line 213 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, "");
#line 1683 "wizard-source.c"
	}
}


static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self) {
#line 217 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 218 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
#line 1693 "wizard-source.c"
}


static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_enter_url_button_clicked ((BoxesWizardSource*) self);
#line 1700 "wizard-source.c"
}


static void boxes_wizard_source_on_url_entry_activated (BoxesWizardSource* self) {
#line 222 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 223 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 1709 "wizard-source.c"
}


static void _boxes_wizard_source_on_url_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_url_entry_activated ((BoxesWizardSource*) self);
#line 1716 "wizard-source.c"
}


static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self) {
#line 227 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 228 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 229 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_MAIN);
#line 1727 "wizard-source.c"
}


static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_url_back_button_clicked ((BoxesWizardSource*) self);
#line 1734 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_data_free (gpointer _data) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _data;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceAddMediaEntriesData, _data_);
#line 1745 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	BoxesWizardSource* _tmp0_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceAddMediaEntriesData);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_callback_ == NULL) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_task_complete_ = TRUE;
#line 1760 "wizard-source.c"
	}
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_source_add_media_entries_data_free);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1770 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_task_complete_ = TRUE;
#line 1780 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_task_complete_ = TRUE;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1796 "wizard-source.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1803 "wizard-source.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 1810 "wizard-source.c"
}


static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 1819 "wizard-source.c"
		goto _state_0;
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 1823 "wizard-source.c"
		goto _state_1;
		default:
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 1828 "wizard-source.c"
	}
	_state_0:
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = _data_->self->media_manager;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_state_ = 1;
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_media_manager_list_installer_medias (_data_->_tmp0_, boxes_wizard_source_add_media_entries_ready, _data_);
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1839 "wizard-source.c"
	_state_1:
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = boxes_media_manager_list_installer_medias_finish (_data_->_tmp0_, _data_->_res_);
#line 233 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->medias = _data_->_tmp1_;
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = _data_->self->priv->media_vbox;
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp2_);
#line 1849 "wizard-source.c"
	{
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->child_collection = _data_->_tmp3_;
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (_data_->child_it = _data_->child_collection; _data_->child_it != NULL; _data_->child_it = _data_->child_it->next) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->child = (GtkWidget*) _data_->child_it->data;
#line 1857 "wizard-source.c"
			{
#line 236 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = _data_->child;
#line 236 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp4_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp4_) : NULL)->media;
#line 236 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 236 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->child_media = _data_->_tmp6_;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->obsolete = TRUE;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = _data_->medias;
#line 1871 "wizard-source.c"
				{
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->media_collection = _data_->_tmp7_;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					for (_data_->media_it = _data_->media_collection; _data_->media_it != NULL; _data_->media_it = _data_->media_it->next) {
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp8_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->media_it->data);
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->media = _data_->_tmp8_;
#line 1881 "wizard-source.c"
						{
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp9_ = _data_->child_media;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = _data_->_tmp9_->device_file;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = _data_->media;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = _data_->_tmp11_->device_file;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp10_, _data_->_tmp12_) == 0) {
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_data_->obsolete = FALSE;
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->media);
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								break;
#line 1899 "wizard-source.c"
							}
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->media);
#line 1903 "wizard-source.c"
						}
					}
				}
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = _data_->obsolete;
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp13_) {
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = _data_->self->priv->media_vbox;
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = _data_->child;
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					gtk_container_remove ((GtkContainer*) _data_->_tmp14_, _data_->_tmp15_);
#line 1917 "wizard-source.c"
				}
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->child_media);
#line 1921 "wizard-source.c"
			}
		}
#line 235 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_data_->child_collection);
#line 1926 "wizard-source.c"
	}
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = _data_->medias;
#line 1930 "wizard-source.c"
	{
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_vala1_media_collection = _data_->_tmp16_;
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (_data_->_vala1_media_it = _data_->_vala1_media_collection; _data_->_vala1_media_it != NULL; _data_->_vala1_media_it = _data_->_vala1_media_it->next) {
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_vala1_media_it->data);
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->_vala1_media = _data_->_tmp17_;
#line 1940 "wizard-source.c"
			{
#line 251 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->nouveau = TRUE;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = _data_->self->priv->media_vbox;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp18_);
#line 1948 "wizard-source.c"
				{
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_vala1_child_collection = _data_->_tmp19_;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					for (_data_->_vala1_child_it = _data_->_vala1_child_collection; _data_->_vala1_child_it != NULL; _data_->_vala1_child_it = _data_->_vala1_child_it->next) {
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->_vala1_child = (GtkWidget*) _data_->_vala1_child_it->data;
#line 1956 "wizard-source.c"
						{
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = _data_->_vala1_child;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp20_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp20_) : NULL)->media;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = _g_object_ref0 (_data_->_tmp21_);
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_vala1_child_media = _data_->_tmp22_;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp23_ = _data_->_vala1_child_media;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = _data_->_tmp23_->device_file;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp25_ = _data_->_vala1_media;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp26_ = _data_->_tmp25_->device_file;
#line 254 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp24_, _data_->_tmp26_) == 0) {
#line 255 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_data_->nouveau = FALSE;
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->_vala1_child_media);
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								break;
#line 1982 "wizard-source.c"
							}
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->_vala1_child_media);
#line 1986 "wizard-source.c"
						}
					}
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_g_list_free0 (_data_->_vala1_child_collection);
#line 1991 "wizard-source.c"
				}
#line 261 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp27_ = _data_->nouveau;
#line 261 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp27_) {
#line 262 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp28_ = _data_->_vala1_media;
#line 262 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					boxes_wizard_source_add_media_entry (_data_->self, _data_->_tmp28_);
#line 2001 "wizard-source.c"
				}
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 2005 "wizard-source.c"
			}
		}
	}
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp29_ = _data_->self->priv->media_vbox;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp30_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp29_);
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = g_list_length (_data_->_tmp31_);
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = _data_->_tmp32_ == ((guint) 0);
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_list_free0 (_data_->_tmp31_);
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_tmp33_) {
#line 267 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp34_ = _data_->self->priv->media_scrolled;
#line 267 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_widget_hide ((GtkWidget*) _data_->_tmp34_);
#line 2027 "wizard-source.c"
	}
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (_data_->medias);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ != 0) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2039 "wizard-source.c"
		}
	}
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 2046 "wizard-source.c"
}


static Block93Data* block93_data_ref (Block93Data* _data93_) {
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data93_->_ref_count_);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return _data93_;
#line 2055 "wizard-source.c"
}


static void block93_data_unref (void * _userdata_) {
	Block93Data* _data93_;
	_data93_ = (Block93Data*) _userdata_;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data93_->_ref_count_)) {
#line 2064 "wizard-source.c"
		BoxesWizardSource* self;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self = _data93_->self;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data93_->entry);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data93_->media);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block93Data, _data93_);
#line 2076 "wizard-source.c"
	}
}


static void __lambda69_ (Block93Data* _data93_) {
	BoxesWizardSource* self;
	BoxesInstallerMedia* _tmp0_;
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data93_->self;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _data93_->media;
#line 274 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_media_selected (self, _tmp0_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _data93_->entry);
#line 2092 "wizard-source.c"
}


static void ___lambda69__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda69_ (self);
#line 2099 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	Block93Data* _data93_;
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	BoxesWizardMediaEntry* _tmp3_;
	GtkBox* _tmp4_;
	BoxesWizardScrolled* _tmp5_;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_ = g_slice_new0 (Block93Data);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_->_ref_count_ = 1;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_->self = g_object_ref (self);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data93_->media);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_->media = _tmp1_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _data93_->media;
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = boxes_wizard_media_entry_new (_tmp2_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp3_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_->entry = _tmp3_;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->media_vbox;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) _tmp4_, (GtkWidget*) _data93_->entry);
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_data ((GtkButton*) _data93_->entry, "clicked", (GCallback) ___lambda69__gtk_button_clicked, block93_data_ref (_data93_), (GClosureNotify) block93_data_unref, 0);
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = self->priv->media_scrolled;
#line 279 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show ((GtkWidget*) _tmp5_);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block93_data_unref (_data93_);
#line 270 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data93_ = NULL;
#line 2151 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	_data_ = _data;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData, _data_);
#line 2162 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	BoxesWizardSource* _tmp0_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_callback_ == NULL) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_task_complete_ = TRUE;
#line 2177 "wizard-source.c"
	}
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 2187 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_task_complete_ = TRUE;
#line 2197 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_task_complete_ = TRUE;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 2213 "wizard-source.c"
}


static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 2222 "wizard-source.c"
		goto _state_0;
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 2226 "wizard-source.c"
		goto _state_1;
		default:
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 2231 "wizard-source.c"
	}
	_state_0:
	{
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_state_ = 1;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_libvirt_system_importer_new (boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready, _data_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 2241 "wizard-source.c"
		_state_1:
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp1_ = boxes_libvirt_system_importer_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp0_ = _data_->_tmp1_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2249 "wizard-source.c"
			goto __catch127_g_error;
		}
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (_data_->self, _data_->_tmp0_);
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 2256 "wizard-source.c"
	}
	goto __finally127;
	__catch127_g_error:
	{
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_inner_error_ = NULL;
#line 286 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp2_ = _data_->_error_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp3_ = _data_->_tmp2_->message;
#line 286 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:286: %s", _data_->_tmp3_);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_data_->_error_);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_data_->_state_ != 0) {
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			while (_data_->_task_complete_ != TRUE) {
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2281 "wizard-source.c"
			}
		}
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_unref (_data_->_async_result);
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 2288 "wizard-source.c"
	}
	__finally127:
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_data_->_inner_error_);
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_unref (_data_->_async_result);
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 2301 "wizard-source.c"
	}
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp4_ = _data_->self->priv->libvirt_sys_import_label;
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp5_ = _data_->self->priv->_libvirt_sys_importer;
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp6_ = boxes_libvirt_system_importer_get_wizard_menu_label (_data_->_tmp5_);
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_data_->_tmp4_, _data_->_tmp8_);
#line 290 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_data_->_tmp8_);
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp9_ = _data_->self->priv->libvirt_sys_import_button;
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _data_->_tmp9_);
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ != 0) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2329 "wizard-source.c"
		}
	}
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 2336 "wizard-source.c"
}


static void __lambda134_ (BoxesWizardSource* self, const gchar* uri) {
	const gchar* _tmp0_;
	GtkButton* _tmp1_;
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (uri != NULL);
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = uri;
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_uri (self, _tmp0_);
#line 299 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_install_media (self, NULL);
#line 300 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 302 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->select_file_button;
#line 302 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp1_);
#line 2357 "wizard-source.c"
}


static void ___lambda134__boxes_wizard_window_file_chosen_func (const gchar* uri, gpointer self) {
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda134_ ((BoxesWizardSource*) self, uri);
#line 2364 "wizard-source.c"
}


static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self) {
	BoxesAppWindow* _tmp0_;
	BoxesWizardWindow* _tmp1_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->window;
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_->wizard_window;
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_window_show_file_chooser (_tmp1_, ___lambda134__boxes_wizard_window_file_chosen_func, g_object_ref (self), g_object_unref);
#line 2379 "wizard-source.c"
}


static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_select_file_button_clicked ((BoxesWizardSource*) self);
#line 2386 "wizard-source.c"
}


static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self) {
	GtkButton* _tmp0_;
#line 307 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 308 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = TRUE;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 311 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->libvirt_sys_import_button;
#line 311 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp0_);
#line 2402 "wizard-source.c"
}


static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_libvirt_sys_import_button_clicked ((BoxesWizardSource*) self);
#line 2409 "wizard-source.c"
}


static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	GError * _inner_error_ = NULL;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 2419 "wizard-source.c"
	{
		BoxesInstallerMedia* _tmp0_ = NULL;
		BoxesMediaManager* _tmp1_;
		BoxesInstallerMedia* _tmp2_;
		BoxesInstallerMedia* _tmp3_;
		BoxesInstallerMedia* _tmp4_;
		const gchar* _tmp5_;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->media_manager;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = media;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = boxes_media_manager_create_installer_media_from_media (_tmp1_, _tmp2_, &_inner_error_);
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp3_;
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2437 "wizard-source.c"
			goto __catch128_g_error;
		}
#line 316 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, _tmp0_);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = media;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _tmp4_->device_file;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp5_);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp0_);
#line 2452 "wizard-source.c"
	}
	goto __finally128;
	__catch128_g_error:
	{
		GError* _error_ = NULL;
		BoxesInstallerMedia* _tmp6_;
		const gchar* _tmp7_;
		GError* _tmp8_;
		const gchar* _tmp9_;
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 321 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = media;
#line 321 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = _tmp6_->device_file;
#line 321 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = _error_;
#line 321 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _tmp8_->message;
#line 321 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_warning ("wizard-source.vala:321: Failed to setup installation media '%s': %s", _tmp7_, _tmp9_);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 2478 "wizard-source.c"
	}
	__finally128:
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 2489 "wizard-source.c"
	}
}


BoxesWizardSource* boxes_wizard_source_construct (GType object_type) {
	BoxesWizardSource * self = NULL;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardSource*) g_object_new (object_type, NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 2500 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_new (void) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_source_construct (BOXES_TYPE_WIZARD_SOURCE);
#line 2507 "wizard-source.c"
}


GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_selected;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2522 "wizard-source.c"
}


void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value) {
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_selected (self) != value) {
#line 2531 "wizard-source.c"
		GtkWidget* _tmp0_;
		GtkWidget* _tmp1_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_selected);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_selected = _tmp1_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_SELECTED]);
#line 2544 "wizard-source.c"
	}
}


const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self) {
	const gchar* result;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp1_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2563 "wizard-source.c"
}


void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value) {
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_entry_set_text (_tmp0_, _tmp1_);
#line 104 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_URI]);
#line 2580 "wizard-source.c"
}


BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_install_media;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2595 "wizard-source.c"
}


static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value) {
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_install_media (self) != value) {
#line 2604 "wizard-source.c"
		BoxesInstallerMedia* _tmp0_;
		BoxesInstallerMedia* _tmp1_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_install_media);
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_install_media = _tmp1_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_INSTALL_MEDIA]);
#line 2617 "wizard-source.c"
	}
}


BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self) {
	BoxesLibvirtSystemImporter* result;
	BoxesLibvirtSystemImporter* _tmp0_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_libvirt_sys_importer;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2633 "wizard-source.c"
}


static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value) {
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_libvirt_sys_importer (self) != value) {
#line 2642 "wizard-source.c"
		BoxesLibvirtSystemImporter* _tmp0_;
		BoxesLibvirtSystemImporter* _tmp1_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_libvirt_sys_importer = _tmp1_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER]);
#line 2655 "wizard-source.c"
	}
}


static gboolean _vala_string_array_contains (const gchar* * stack, int stack_length, const gchar* needle) {
	int i;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	for (i = 0; i < stack_length; i++) {
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return TRUE;
#line 2668 "wizard-source.c"
		}
	}
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 2673 "wizard-source.c"
}


gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self) {
	gboolean result;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	static const gchar* supported_schemes[] = {"http", "https"};
#line 2681 "wizard-source.c"
	gchar* scheme = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_;
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_wizard_source_get_uri (self);
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_;
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = g_uri_parse_scheme (_tmp1_);
#line 136 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	scheme = _tmp2_;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = scheme;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp4_ != NULL) {
#line 2702 "wizard-source.c"
		const gchar* _tmp5_;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = scheme;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = _vala_string_array_contains (supported_schemes, G_N_ELEMENTS (supported_schemes), _tmp5_);
#line 2708 "wizard-source.c"
	} else {
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = FALSE;
#line 2712 "wizard-source.c"
	}
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp3_;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (scheme);
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2720 "wizard-source.c"
}


BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self) {
	BoxesSourcePage result;
	BoxesSourcePage _tmp0_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_page;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2735 "wizard-source.c"
}


void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value) {
	BoxesSourcePage _tmp0_;
	BoxesSourcePage _tmp1_;
	const gchar* _tmp2_;
	GtkWidget* _tmp3_;
	BoxesSourcePage _tmp5_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->_page = _tmp0_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = BOXES_WIZARD_SOURCE_page_names[_tmp1_];
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->priv->_selected;
#line 150 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ != NULL) {
#line 2761 "wizard-source.c"
		GtkWidget* _tmp4_;
#line 151 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = self->priv->_selected;
#line 151 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_widget_grab_focus (_tmp4_);
#line 2767 "wizard-source.c"
	}
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = value;
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_tmp5_) {
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 2775 "wizard-source.c"
		{
			GtkBox* _tmp6_;
#line 154 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp6_ = self->priv->main_vbox;
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 157 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			break;
#line 2786 "wizard-source.c"
		}
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 2790 "wizard-source.c"
		{
			GtkEntry* _tmp7_;
			GtkEntry* _tmp8_;
#line 159 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp7_ = self->url_entry;
#line 159 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_signal_emit_by_name ((GtkEditable*) _tmp7_, "changed");
#line 160 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp8_ = self->url_entry;
#line 160 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			break;
#line 2804 "wizard-source.c"
		}
		default:
#line 152 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 2809 "wizard-source.c"
	}
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_PAGE]);
#line 2813 "wizard-source.c"
}


static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSource * self;
	BoxesMediaManager* _tmp0_;
	GtkBox* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_;
	gint num_visible = 0;
	BoxesWizardScrolled* _tmp4_;
	gint _tmp5_;
	BoxesWizardScrolled* _tmp6_;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	GtkBox* _tmp9_;
#line 166 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_source_parent_class);
#line 166 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 166 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->media_manager = _tmp0_;
#line 168 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->main_vbox;
#line 168 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gdk_screen_height ();
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ > 800) {
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 5;
#line 2854 "wizard-source.c"
	} else {
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 4;
#line 2858 "wizard-source.c"
	}
#line 170 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	num_visible = _tmp2_;
#line 171 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->media_scrolled;
#line 171 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = num_visible;
#line 171 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_setup (_tmp4_, _tmp5_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->media_scrolled;
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_->vbox;
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 172 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->media_vbox = _tmp8_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->url_entry_vbox;
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_draw_as_css_box ((GtkWidget*) _tmp9_);
#line 175 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility (self, NULL, NULL);
#line 176 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 177 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 166 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return obj;
#line 2890 "wizard-source.c"
}


static void boxes_wizard_source_class_init (BoxesWizardSourceClass * klass) {
	gint BoxesWizardSource_private_offset;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_parent_class = g_type_class_peek_parent (klass);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSourcePrivate));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_source_get_property;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_source_set_property;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_source_constructor;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_source_finalize;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_SELECTED, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_SELECTED] = g_param_spec_object ("selected", "selected", "selected", gtk_widget_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_URI, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_URI] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_INSTALL_MEDIA, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_INSTALL_MEDIA] = g_param_spec_object ("install-media", "install-media", "install-media", BOXES_TYPE_INSTALLER_MEDIA, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER] = g_param_spec_object ("libvirt-sys-importer", "libvirt-sys-importer", "libvirt-sys-importer", BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED] = g_param_spec_boolean ("download-required", "download-required", "download-required", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_PAGE, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_PAGE] = g_param_spec_enum ("page", "page", "page", BOXES_TYPE_SOURCE_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardSource_private_offset = g_type_class_get_instance_private_offset (klass);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-source.ui");
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL] = g_signal_new ("activated", BOXES_TYPE_WIZARD_SOURCE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "main_vbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, main_vbox));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_scrolled", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, media_scrolled));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry_vbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, url_entry_vbox));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry", FALSE, G_STRUCT_OFFSET (BoxesWizardSource, url_entry));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_file_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, select_file_button));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_button));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_label", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_label));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_enter_url_button_clicked", G_CALLBACK(_boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_url_entry_activated", G_CALLBACK(_boxes_wizard_source_on_url_entry_activated_gtk_entry_activate));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_url_back_button_clicked", G_CALLBACK(_boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_select_file_button_clicked", G_CALLBACK(_boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_libvirt_sys_import_button_clicked", G_CALLBACK(_boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked));
#line 2950 "wizard-source.c"
}


static void boxes_wizard_source_instance_init (BoxesWizardSource * self) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SOURCE_GET_PRIVATE (self);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SCROLLED);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 2961 "wizard-source.c"
}


static void boxes_wizard_source_finalize (GObject * obj) {
	BoxesWizardSource * self;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 106 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 107 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 113 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->main_vbox);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_scrolled);
#line 117 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_entry_vbox);
#line 119 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->url_entry);
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->select_file_button);
#line 123 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_button);
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_label);
#line 127 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->window);
#line 129 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->finalize (obj);
#line 2997 "wizard-source.c"
}


GType boxes_wizard_source_get_type (void) {
	static volatile gsize boxes_wizard_source_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSource), 0, (GInstanceInitFunc) boxes_wizard_source_instance_init, NULL };
		GType boxes_wizard_source_type_id;
		boxes_wizard_source_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesWizardSource", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_source_type_id__volatile, boxes_wizard_source_type_id);
	}
	return boxes_wizard_source_type_id__volatile;
}


static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_selected (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_string (value, boxes_wizard_source_get_uri (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_install_media (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_libvirt_sys_importer (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_boolean (value, boxes_wizard_source_get_download_required (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_enum (value, boxes_wizard_source_get_page (self));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3054 "wizard-source.c"
		default:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3060 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, g_value_get_object (value));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, g_value_get_string (value));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, g_value_get_object (value));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (self, g_value_get_object (value));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_page (self, g_value_get_enum (value));
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3100 "wizard-source.c"
		default:
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3106 "wizard-source.c"
	}
}



